@@ -18,9 +18,11 @@ def read_config(config_file: Path="./config.yaml"):
     return Box(context, default_box=True)
 
 
-_config_file = list(Path(os.getcwd()).glob("**/*config.yml") and Path(os.getcwd()).glob("**/*config.yaml") and Path().cwd().glob("*config*.yml") and Path().cwd().glob("*config*.yaml"))
-_config_file = _config_file if _config_file else list(Path(__file__).parent.glob("config.yml"))
-assert len(_config_file) == 1, "Please provide a configuration file that has a '*config.yaml' name structure"
+_config_file = list(Path.cwd().glob("*config*"))
+if not _config_file:
+    _config_file = [get_config_path() / 'config.yml']
+    logging.warning('Using default configuration file (not the user defined one)')
+assert len(_config_file) >= 1, "Please provide a configuration file that has a '*config.yaml' name structure"
 config = read_config(config_file=_config_file[0])
 
 # Add global configuration
@@ -34,3 +36,4 @@ os.makedirs(config.path.logs if config.path.logs else Path().cwd() / "logs", exi
 with open(Path(__file__).parent / "logger_config.yml", "r") as ymlfile:
     log_config = yaml.safe_load(ymlfile)
 logging.config.dictConfig(log_config)
+
