@@ -7,4 +7,6 @@ from .OpenFoamReader import OpenFoamReader
 from .StreamlineReader import StreamlineReader
 from .VtkReader import VtkReader
 from .iGPReader.io.iGPReader import iGPReader
-from .ConnectFlowReader import ConnectFlowReader
\ No newline at end of file
+from .ConnectFlowReader import ConnectFlowReader
+from .PflotranReader import PflotranReader
+from .PflotranObservationPointReader import PflotranObservationPointReader
\ No newline at end of file
