@@ -12,10 +12,10 @@ class CentroidReaderCase(unittest.TestCase):
     This class tests the iGPReader[PyFLOTRAN.readers.iGPReader.io.iGPReader.iGPReader] class implementation
     """
     def setUp(self) -> None:
-        self.centroid_reader = CentroidReader(test_data_path() / "centroid_reader_data.csv", header=True, split_key=",")
+        self.centroid_reader = CentroidReader(test_data_path() / "centroid_reader_data.csv", header=True, separator=",")
 
     def test_centroid_data(self):
-        self.assertEqual(self.centroid_reader.get_data()[0][0], 0.0)
+        self.assertEqual(self.centroid_reader.get_data(as_dataframe=False)[0][0], 0.0)
 
     def test_write_data(self):
         write_path = Path().cwd() / "test.csv"
