@@ -13,6 +13,7 @@ except:
     from PyFLOTRAN.paraview_processor.filters import BaseFilter
 import pandas as pd
 from box import Box
+from scipy.stats import lognorm
 
 
 def interpolate_permeability_anisotropic(perm_filename, mesh_filename=None, mesh=None):
@@ -172,4 +173,99 @@ def read_local_config():
     _config_file = _config_file if _config_file else list(Path(__file__).parent.glob("config.yml"))
     assert len(_config_file) == 1, "Please provide a configuration file that has a '*config.yaml' name structure"
     config = read_config(config_file=_config_file[0])
-    return config
\ No newline at end of file
+    return config
+
+
+def sample_values_from_dict(input_dict: dict, n: int, write_to_file=True, return_generator=False) -> list:
+    """
+    This method reads a dictionary and generates n samples from them based on the
+    following criteria.
+
+    The structure of the dictionary should be as follows:
+
+    name_of_dict:
+        material_name_i:
+            type: type of the desired distribution
+            option_keys: these keys depend on the chosen distribution type
+        material_name_i:
+
+    Type of implemented distributions:
+        constant[value]: sets a constant value for the variable
+        log_normal[mean, std]: generates a log-normal distribution based on the mean, std values
+        specified in natural scale.
+
+    Args:
+        write_to_file: optional argument that writes a csv file with the generated cases. Defaults to True.
+        d: dictionary to extract the samples from
+        n: integer specifying the number of generated samples
+    Returns:
+        A dictionary containing the sampled results
+    """
+    class BaseDistribution:
+        def __init__(self):
+            pass
+        def run(self) -> float:
+            """
+            This method generates a value of the given distribution
+            Returns: a float number containing the value
+            """
+
+    class ConstantDistribution(BaseDistribution):
+        def __init__(self, value):
+            super().__init__()
+            self.value = value
+
+        def run(self):
+            return self.value
+
+    class NormalDistribution(BaseDistribution):
+        def __init__(self, mean, std, log=False):
+            super().__init__()
+            self.mean = float(mean)
+            self.std = float(std)
+            self.log = log
+
+        def run(self):
+            if not self.log:
+                return np.random.normal(self.mean, self.std)
+            else:
+                return np.random.lognormal(self.mean, self.std)
+
+    # Process each material and create sample generators
+    generator_dict = {}
+    for material in input_dict:
+        material_dict = input_dict[material]
+        if material_dict['type'] == 'constant':
+            generator_dict[material] = ConstantDistribution(value=material_dict['value'])
+        elif material_dict['type'] == 'normal':
+            generator_dict[material] = NormalDistribution(mean=material_dict['mean'],
+                                                          std=material_dict['std'],
+                                                          )
+        elif material_dict['type'] == 'log-normal' or material_dict['type'] == 'log_normal':
+            generator_dict[material] = NormalDistribution(mean=material_dict['mean'],
+                                                          std=material_dict['std'],
+                                                          log=True,
+                                                          )
+        elif material_dict['type'] == 'log_normal-two_values':
+            y_min_log = np.log(float(material_dict['y_min']))
+            y_max_log = np.log(float(material_dict['y_max']))
+            mean = (y_min_log + y_max_log) / 2.0
+            std = (mean - y_min_log) / 2.0
+
+            generator_dict[material] = NormalDistribution(mean=mean,
+                                                          std=std,
+                                                          log=True,
+                                                          )
+
+    final_list = []
+    for sample_id in range(n):
+        current_case = {}
+        for generator in generator_dict:
+            current_case[generator] = generator_dict[generator].run()
+        final_list.append(current_case)
+    if write_to_file:
+        df_test = pd.DataFrame(final_list)
+        df_test.to_csv('SA_cases.csv', index=False)
+    if return_generator:
+        return generator_dict
+    return final_list
